Scripting Tutorials
===================

In order to best make use of the MJOLNIR software, a set of tutorials has been written. They are meant to serve as examples of how one could go about 
creating the most general graphs and how one uses the package in general. These tutorials are split into four different categories with different targets
in mind. For the novice, the tutorials of the 'Quick and simple examples' group are introductions into simple visualization. If one is not completely 
satisfied with the range of possibilities presented here, the 'Advanced and in-depth examples' are to be regarded. 

The categories of 'Tools' and 'Instrument relevant' are a collections of showcasing examples of how to use the build-in tools as well as creating 
virtual representations of instruments. By the use of the latter, one can also create new normalization tables to be used when converting raw 
data files into nxs files.

If specific features are poorly documented or simply missing from the tutorials or from the functionality of MJOLNIR, please feel free to either 
create an issue at the `Git Hub-page <https://github.com/Jakob-Lass/MJOLNIR>`_ or write an `email <mailto:lass.jakob@gmail.com>`_ .


Quick and simple examples
-------------------------

.. toctree::
   :glob:
   :maxdepth: 1

   Quick/*

Advanced and in-depth examples
------------------------------

.. toctree::
   :glob:
   :maxdepth: 1

   Advanced/*
   

Tools
-----

.. toctree::
   :glob:
   :maxdepth: 1

   Tools/*


Instrument relevant
-------------------

.. toctree::
   :glob:
   :maxdepth: 1

   Instrument/*



